@@ -36,8 +36,33 @@ static void gnome_db_list_class_init (GnomeDbListClass *klass);
 static void gnome_db_list_init       (GnomeDbList *list, GnomeDbListClass *klass);
 static void gnome_db_list_finalize   (GObject *object);
 
+enum {
+	ROW_SELECTED,
+	SELECTION_CLEARED,
+	LAST_SIGNAL
+};
+
+static gint list_signals[LAST_SIGNAL];
 static GObjectClass *parent_class = NULL;
 
+/*
+ * Callbacks
+ */
+
+static void
+grid_row_selected_cb (GnomeDbGrid *grid, gint row, gpointer user_data)
+{
+	g_return_if_fail (GNOME_DB_IS_LIST (user_data));
+	g_signal_emit (G_OBJECT (user_data), list_signals[ROW_SELECTED], 0, row);
+}
+
+static void
+grid_selection_cleared_cb (GnomeDbGrid *grid, gpointer user_data)
+{
+	g_return_if_fail (GNOME_DB_IS_LIST (user_data));
+	g_signal_emit (G_OBJECT (user_data), list_signals[SELECTION_CLEARED], 0);
+}
+
 /*
  * GnomeDbList class implementation
  */
@@ -49,6 +74,23 @@ gnome_db_list_class_init (GnomeDbListClass *klass)
 
 	parent_class = g_type_class_peek_parent (klass);
 
+	list_signals[ROW_SELECTED] =
+		g_signal_new ("row_selected",
+			      G_TYPE_FROM_CLASS (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (GnomeDbGridClass, row_selected),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__INT,
+			      G_TYPE_NONE, 1, G_TYPE_INT);
+	list_signals[SELECTION_CLEARED] =
+		g_signal_new ("selection_cleared",
+			      G_TYPE_FROM_CLASS (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (GnomeDbGridClass, row_selected),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__VOID,
+			      G_TYPE_NONE, 0);
+
 	object_class->finalize = gnome_db_list_finalize;
 }
 
@@ -63,6 +105,10 @@ gnome_db_list_init (GnomeDbList *list, GnomeDbListClass *klass)
 
 	/* set up widgets */
 	list->priv->grid = gnome_db_new_grid_widget (NULL);
+	g_signal_connect (G_OBJECT (list->priv->grid), "row_selected",
+			  G_CALLBACK (grid_row_selected_cb), list);
+	g_signal_connect (G_OBJECT (list->priv->grid), "selection_cleared",
+			  G_CALLBACK (grid_selection_cleared_cb), list);
 	gnome_db_grid_hide_column_titles (GNOME_DB_GRID (list->priv->grid));
 	gtk_box_pack_start (GTK_BOX (list), list->priv->grid, TRUE, TRUE, 0);
 }
@@ -142,6 +188,16 @@ gnome_db_list_new_with_model (GdaDataModel *model, gint col)
 	return list;
 }
 
+/**
+ * gnome_db_list_get_model
+ */
+GdaDataModel *
+gnome_db_list_get_model (GnomeDbList *list)
+{
+	g_return_val_if_fail (GNOME_DB_IS_LIST (list), NULL);
+	return list->priv->data_model;
+}
+
 /**
  * gnome_db_list_set_model
  * @list: a #GnomeDbList widget.
