@@ -1,5 +1,5 @@
 /* GNOME DB library
- * Copyright (C) 1999-2000 Rodrigo Moya
+ * Copyright (C) 1999-2001 Rodrigo Moya
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -20,6 +20,7 @@
 #if !defined(_LIBGNOME_DB_H_)
 #  define _LIBGNOME_DB_H_
 
+#include <libgda/libgda.h>
 #include <libgnomedb/gnome-db-browser.h>
 #include <libgnomedb/gnome-db-connection-selector.h>
 #include <libgnomedb/gnome-db-control.h>
@@ -33,6 +34,17 @@
 #include <libgnomedb/gnome-db-login.h>
 #include <libgnomedb/gnome-db-login-dialog.h>
 #include <libgnomedb/gnome-db-model.h>
+#include <libgnomedb/gnome-db-table-editor.h>
 #include <libgnomedb/gnome-db-util.h>
+#include <libgnomedb/gnome-db-window.h>
+
+G_BEGIN_DECLS
+
+void gnome_db_init (const gchar *app_id, const gchar *version, gint nargs, gchar *args[]);
+
+void gnome_db_main_run (GdaInitFunc init_func, gpointer user_data);
+void gnome_db_main_quit (void);
+
+G_END_DECLS
 
 #endif
